﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Diagnostics;

namespace Common
{
    public class PerfCounters
    {
        public const string CounterCategoryName = "Strategy Alerts";
        public const string PriceUpdatesTotal = "Total Price Updates";
        public const string PriceUpdatesPerSec = "Price Updates/sec";
        public const string PositionEvalsTotal = "Total Position Evaluations";
        public const string PositionEvalsPerSec = "Position Evaluations/sec";

        public static void InstallCounters()
        {
            try
            {
                if (!PerformanceCounterCategory.Exists(PerfCounters.CounterCategoryName))
                {
                    CounterCreationDataCollection counterDataCollection = new CounterCreationDataCollection();

                    // Add the counters to the category.
                    CounterCreationData priceUpdatesTotal = new CounterCreationData();
                    priceUpdatesTotal.CounterType = PerformanceCounterType.NumberOfItems64;
                    priceUpdatesTotal.CounterName = PerfCounters.PriceUpdatesTotal;
                    counterDataCollection.Add(priceUpdatesTotal);

                    CounterCreationData priceUpdatesPerSec = new CounterCreationData();
                    priceUpdatesPerSec.CounterType = PerformanceCounterType.RateOfCountsPerSecond32;
                    priceUpdatesPerSec.CounterName = PerfCounters.PriceUpdatesPerSec;
                    counterDataCollection.Add(priceUpdatesPerSec);

                    CounterCreationData positionUpdatesTotal = new CounterCreationData();
                    positionUpdatesTotal.CounterType = PerformanceCounterType.NumberOfItems64;
                    positionUpdatesTotal.CounterName = PerfCounters.PositionEvalsTotal;
                    counterDataCollection.Add(positionUpdatesTotal);

                    CounterCreationData positionUpdatesPerSec = new CounterCreationData();
                    positionUpdatesPerSec.CounterType = PerformanceCounterType.RateOfCountsPerSecond32;
                    positionUpdatesPerSec.CounterName = PerfCounters.PositionEvalsPerSec;
                    counterDataCollection.Add(positionUpdatesPerSec);

                    // Register the new category with Windows.
                    PerformanceCounterCategory.Create(PerfCounters.CounterCategoryName,
                        "Counters to measure Strategy Alerts activity.",
                        PerformanceCounterCategoryType.SingleInstance, counterDataCollection);

                    Console.WriteLine("Successfully installed performance category '{0}'.", PerfCounters.CounterCategoryName);

                }
            }
            catch (Exception ex)
            {
                Console.WriteLine("Counter installation failed. " + ex.Message);
            }
        }

        public static void UninstallCounters()
        {
            try
            {
                if (PerformanceCounterCategory.Exists(PerfCounters.CounterCategoryName))
                {
                    PerformanceCounterCategory.Delete(PerfCounters.CounterCategoryName);
                    Console.WriteLine("Successfully uninstalled performance category '{0}'.", PerfCounters.CounterCategoryName);
                }
                else
                {
                    Console.WriteLine("Could not find performance category '{0}'. Nothing to do.", PerfCounters.CounterCategoryName);
                }
            }
            catch (Exception ex)
            {
                Console.WriteLine("An error occurred while uninstalling the performance counters.");
                Console.WriteLine(ex.ToString());
            }
        }

       
    }
}
